View source: R/poissmix_task.R
| poissmix_task | R Documentation |
Poisson mixture parameter estimation problem with Hasselblad data.
poissmix_task()
A list containing all components needed for benchmarking the Poisson mixture problem using Hasselblad data.
initfn |
Parameter random initializing function |
fixptfn |
Updating function for the fixed point iteration problem |
objfn |
Function calculating the objective value for current parameter |
... |
Other arguments required in functions above |
Hasselblad V (1966). Estimation of parameters for a mixture of normal distributions. Technometrics, 8(3): 431–444.
## Not run:
set.seed(54321)
benchmark(
poissmix_task,
algorithm=c("raw", "squarem", "daarem", "pem", "qn", "nes"),
ntimes = 200
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.