| summary.benchmark | R Documentation |
benchmark ClassSummary Method for benchmark Class
## S3 method for class 'benchmark' summary(object, rate_tol = 0.1, loss_tol = NULL, ci_level = 0.95, ...)
object |
benchmark class output by benchmark function |
rate_tol |
A value in (0, 1). All repetitions with loss bigger than (1+rate_tol) * minimum_loss would be considered as a failure. |
loss_tol |
A real value. All repetitions with loss bigger than |
ci_level |
A value in (0, 1) for confidence level of confidence intervals in the result |
... |
Other arguments for summary function. |
If loss_tol is not NULL, rate_tol will not be used.
A data frame containing useful values illustrating the performance of different algorithms.
## Not run:
set.seed(54321)
out = benchmark("poissmix", c("raw", "squarem", "daarem", "pem", "qn", "nes"), ntimes=100)
summary(out)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.