| tsne_task | R Documentation |
A function that will generate the task list that can be used to benchmark the acceleration of tSNE in COIL-20 data
tsne_task(perplexity = 30, rho = 2e-07, sd = 0.01)
perplexity |
Perplexity value used to calculate the similarity matrix in original space before embedding |
rho |
Initial Learning rate used in the MM algorithm for tSNE |
sd |
Standard deviation for the random initial embedding coordinates |
A list containing all components needed for benchmarking the problem
initfn |
Parameter random initializing function |
fixptfn |
Updating function for the fixed point iteration problem |
objfn |
Function calculating the objective value for current parameter |
... |
Other arguments required in functions above |
Yang Z, Peltonen J, Kaski S (2015). Majorization-minimization for manifold embedding. In: Artificial Intelligence and Statistics, 1088–1097. PMLR.
## Not run:
set.seed(54321)
problem = tsne_task(rho=5e-6, sd=5e-3)
benchmark(
problem,
algorithm=c("raw", "squarem", "daarem", "pem", "qn", "nes"),
ntimes = 20
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.